aboutsummaryrefslogtreecommitdiffstats
path: root/packages/types/src/index.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/types/src/index.ts')
-rw-r--r--packages/types/src/index.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/types/src/index.ts b/packages/types/src/index.ts
index 58399de4c..fa634420d 100644
--- a/packages/types/src/index.ts
+++ b/packages/types/src/index.ts
@@ -143,11 +143,11 @@ export enum SignatureType {
}
/**
* The Signer Provider Type. Some Signer provider implementations use different message prefixes or implement different
* eth_sign behaviour.
*/
-export enum SignerProviderType {
- EthSign = 'ETH_SIGN',
+export enum SignerType {
+ Default = 'DEFAULT',
Ledger = 'LEDGER',
Metamask = 'METAMASK',
Trezor = 'TREZOR',
@@ -143,11 +143,11 @@ export enum SignatureType {
}
/**
- * The Signer Provider Type. Some Signer provider implementations use different message prefixes or implement different
- * eth_sign behaviour.
+ * The type of the Signer implementation. Some signer implementations use different message prefixes (e.g Trezor) or implement different
+ * eth_sign behaviour (e.g Metamask). Default assumes a spec compliant `eth_sign`.
*/